@@ -20,7 +20,7 @@ from fa_purity.json.primitive.core import (
     PrimitiveTVar,
 )
 from fa_purity.json.primitive.factory import (
-    to_primitive,
+    to_primitive as _to_primitive,
 )
 from fa_purity.json.value.core import (
     JsonValue,
@@ -55,6 +55,11 @@ class Unfolder:
     def value(self) -> UnfoldedJVal:
         return self.jval.unfold()
 
+    def to_primitive(
+        self, prim_type: Type[PrimitiveTVar]
+    ) -> Result[PrimitiveTVar, InvalidType]:
+        return _to_primitive(self.value, prim_type)
+
     def to_list(self) -> UnfoldResult[FrozenList[JsonValue]]:
         if isinstance(self.value, tuple):
             return Result.success(self.value)
@@ -73,7 +78,7 @@ class Unfolder:
         try:
             return self.to_list().map(
                 lambda l: tuple(
-                    to_primitive(i.unfold(), prim_type).unwrap() for i in l
+                    _to_primitive(i.unfold(), prim_type).unwrap() for i in l
                 )
             )
         except UnwrapError[PrimitiveTVar, InvalidType]:
@@ -102,7 +107,7 @@ class Unfolder:
             return self.to_json().map(
                 lambda d: FrozenDict(
                     {
-                        key: to_primitive(val.unfold(), prim_type).unwrap()
+                        key: _to_primitive(val.unfold(), prim_type).unwrap()
                         for key, val in d.items()
                     }
                 )
